______________________________________________________________________

## name: Bug Report about: Report a bug in Shuttle title: "[Bug] " labels: bug

**Shuttle version:** (`shuttle --version`)

**Python version:** (`python --version`)

**OS:**

## Description

A clear description of the bug.

## Steps to Reproduce

1.
1.
1.

## Expected Behavior

What you expected to happen.

## Actual Behavior

What actually happened. Include error messages or logs if applicable.
